/**
 *****************************************************************************
   @file     ADT7410SPI.h
   @brief    Set of functions to interface ADuCM360 to ADT7410 via I2C.
   @version  V0.1
   @author   ADI
   @date     July 2013 

All files for ADuCM360/61 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.

*****************************************************************************/

extern int ADT7410_I2CCFG(char Address,int Resolution,int iMode,int CT,int INT,int INTCTmode,int Faultqueue);
extern int ADT7410_I2CReset(char Address);
extern float ADT7410_I2CGetTemperature(char Address,unsigned char *Status,unsigned char *Config);
extern int ADT7410_I2CID(char Address);
extern int ADT7410_I2C_T_Setpoint(char BusAddress,char REGadd,int RorW,int Value);

/* Parameter values for ADT7410_I2CCFG(char Address,int Resolution,int iMode,int CT,int INT,int INTCTmode,int Faultqueue) */
/* ADT7410 Address */
#define ADT7410_A0_PIN      0 // I2C Serial Bus Address Selection Pin
#define ADT7410_A1_PIN      0 // I2C Serial Bus Address Selection Pin
#define ADT7410_ADDRESS     (0x48 + (ADT7410_A1_PIN << 1) + ADT7410_A0_PIN)
/* Resolution */ 
#define BIT16          1
#define BIT13          0
/* iMode */
#define ADT7410_OP_MODE_CONT_CONV   0
#define ADT7410_OP_MODE_ONE_SHOT    1
#define ADT7410_OP_MODE_1_SPS       2
#define ADT7410_OP_MODE_SHUTDOWN    3
/* CT and INT */
#define Active_Low     0
#define Active_High    1
/* INTCTmode */
#define interrupt_m    0
#define comparator_m   1
/* Faultqueue */
#define ADT7410_FAULT_QUEUE_1_FAULT     0
#define ADT7410_FAULT_QUEUE_2_FAULTS    1
#define ADT7410_FAULT_QUEUE_3_FAULTS    2
#define ADT7410_FAULT_QUEUE_4_FAULTS    3


/* Parameter values for ADT7410_I2C_T_Setpoint(char BusAddress,char REGadd,int RorW,int Value) */
/* REGadd */
#define ADT7410_REG_TEMP_MSB    0x00 // Temperature value MSB
#define ADT7410_REG_TEMP_LSB    0x01 // Temperature value LSB
#define ADT7410_REG_STATUS      0x02 // Status
#define ADT7410_REG_CONFIG      0x03 // Configuration
#define ADT7410_REG_T_HIGH_MSB  0x04 // Temperature HIGH setpoint MSB
#define ADT7410_REG_T_HIGH_LSB  0x05 // Temperature HIGH setpoint LSB
#define ADT7410_REG_T_LOW_MSB   0x06 // Temperature LOW setpoint MSB
#define ADT7410_REG_T_LOW_LSB   0x07 // Temperature LOW setpoint LSB
#define ADT7410_REG_T_CRIT_MSB  0x08 // Temperature CRIT setpoint MSB
#define ADT7410_REG_T_CRIT_LSB  0x09 // Temperature CRIT setpoint LSB
#define ADT7410_REG_HIST        0x0A // Temperature HYST setpoint
#define ADT7410_REG_ID          0x0B // ID
#define ADT7410_REG_RESET       0x2F // Software reset


/* ADT7410 default ID */
#define ADT7410_DEFAULT_ID  0xCB

#define Read 1
#define Write 0



